"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _reactNative = require("react-native");
var _react = _interopRequireWildcard(require("react"));
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const Toast = ({
  message,
  visible = false,
  duration = 2000,
  speed = 300,
  progress = false,
  bounce = false,
  autoDismiss = false,
  centerText = false,
  dismissGesture,
  icon = undefined,
  style = {},
  dismiss
}) => {
  const initialToastPosition = -_reactNative.Dimensions.get('window').height;
  const toastVisiblePosition = _reactNative.Platform.OS == 'ios' ? 50 : 0;
  const progressValue = (0, _reactNativeReanimated.useSharedValue)(_reactNative.Dimensions.get('window').width);
  const topValue = (0, _reactNativeReanimated.useSharedValue)(initialToastPosition);
  let hideToastTimeout;
  const dismissToast = () => {
    topValue.value = (0, _reactNativeReanimated.withTiming)(initialToastPosition, {
      duration: 400
    });
    dismiss();
  };
  (0, _react.useEffect)(() => {
    if (visible) {
      topValue.value = initialToastPosition;
      animateProgressBar();
      if (bounce) {
        topValue.value = (0, _reactNativeReanimated.withSpring)(toastVisiblePosition, {
          mass: .7,
          damping: 10,
          stiffness: 100,
          overshootClamping: false,
          restDisplacementThreshold: 0.01,
          restSpeedThreshold: 2
        });
      } else {
        topValue.value = (0, _reactNativeReanimated.withTiming)(toastVisiblePosition, {
          duration: speed,
          easing: _reactNativeReanimated.Easing.linear
        });
      }
      hideToastTimeout = setTimeout(() => {
        if (autoDismiss) {
          dismissToast();
        }
      }, duration + 1800);
    } else {
      dismissToast();
    }
    return () => {
      clearTimeout(hideToastTimeout);
    };
  }, [visible]);
  const animateProgressBar = () => {
    progressValue.value = _reactNative.Dimensions.get('window').width - 20;
    progressValue.value = (0, _reactNativeReanimated.withTiming)(0, {
      duration: duration + 2000
    });
  };
  const animatedContainerStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      transform: [{
        translateY: topValue.value
      }]
    };
  });
  const animatedProgressBar = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      width: progressValue.value
    };
  });
  const Icon = () => {
    if (!icon) {
      return null;
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        height: 25,
        width: 25,
        borderRadius: 100,
        backgroundColor: 'rgba(0, 0, 0, .1)',
        justifyContent: 'center',
        alignItems: 'center'
      }
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
      source: icon,
      style: {
        width: 14,
        height: 14
      },
      resizeMode: 'contain'
    }));
  };
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.container, {
      top: 0,
      maxHeight: _reactNative.Dimensions.get('window').height - 20
    }, animatedContainerStyle, style]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: dismissGesture
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      padding: 10,
      minHeight: 45,
      flexDirection: 'row',
      alignItems: 'center',
      gap: 5
    }
  }, /*#__PURE__*/_react.default.createElement(Icon, null), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: '#FFF',
      textAlign: centerText ? 'center' : 'left',
      flex: 1
    }
  }, message)), progress && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      backgroundColor: 'rgba(0, 0, 0, .2)',
      height: 6,
      alignItems: 'flex-start',
      borderRadius: 5
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [{
      backgroundColor: 'rgba(0, 0, 0, .2)',
      flex: 1,
      borderRadius: 5
    }, animatedProgressBar]
  })))));
};
const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    zIndex: 10000000000,
    width: _reactNative.Dimensions.get('window').width - 20,
    marginHorizontal: 10,
    marginTop: 15,
    borderRadius: 5
  }
});
var _default = exports.default = Toast;
//# sourceMappingURL=Toast.js.map