"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.ToastManager = void 0;
var _reactNative = require("react-native");
var _react = _interopRequireWildcard(require("react"));
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _Toast = _interopRequireDefault(require("./Toast"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
class ToastManager extends _react.Component {
  defaultToastPosition = -_reactNative.Dimensions.get('window').height;
  defaultToastDuration = 2000;
  constructor(props) {
    super(props);
    ToastManager.toastInstance = this;
    this.state = {
      visible: false,
      duration: this.defaultToastDuration,
      autoDismiss: true,
      dismissMode: 'tap',
      showProgress: false,
      bounce: true,
      centerText: false,
      toastSpeed: 500,
      toastMessage: "",
      backgroundColor: '#aaa',
      style: undefined,
      icon: undefined,
      withIcon: true,
      dismissGesture: _reactNativeGestureHandler.Gesture.Tap().runOnJS(true).onEnd(() => {
        this.hideAllToasts();
      })
    };
    this.progressValue = new _reactNative.Animated.Value(0);
    this.topValue = new _reactNative.Animated.Value(this.defaultToastPosition);
    this.hideToastTimeout;
  }
  static success(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#14A44D'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/check.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static info(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#54B4D3'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static error(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#DC4C64'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/error.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static warning(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#E4A11B'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static styled(text, style, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#E4A11B',
        style
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  show = (text, options) => {
    this.hideAllToasts();
    setTimeout(() => {
      let duration = (options === null || options === void 0 ? void 0 : options.duration) ?? this.defaultToastDuration;
      let autoDismiss = (options === null || options === void 0 ? void 0 : options.autoDismiss) !== true;
      console.log("Showing toast on", this.props);
      this.setState({
        toastMessage: text,
        showProgress: (options === null || options === void 0 ? void 0 : options.progress) ?? false,
        centerText: (options === null || options === void 0 ? void 0 : options.centerText) ?? false,
        bounce: (options === null || options === void 0 ? void 0 : options.bounce) ?? false,
        visible: true,
        duration,
        autoDismiss
      });
      if ((options === null || options === void 0 ? void 0 : options.dismissMode) == 'swipe') {
        this.setState({
          dismissGesture: _reactNativeGestureHandler.Gesture.Pan().runOnJS(true).onUpdate(gesture => {
            if (gesture.translationY < 0) {
              this.hideAllToasts();
            }
          })
        });
      }
    }, 200);
  };
  hideAllToasts = () => {
    this.setState({
      visible: false
    });
  };
  render() {
    return /*#__PURE__*/_react.default.createElement(_Toast.default, {
      visible: this.state.visible,
      duration: this.state.duration,
      progress: this.state.showProgress,
      bounce: this.state.bounce,
      autoDismiss: this.state.autoDismiss,
      centerText: this.state.centerText,
      dismissGesture: this.state.dismissGesture,
      style: [this.state.style ?? {}, {
        backgroundColor: this.state.backgroundColor
      }],
      message: this.state.toastMessage,
      icon: this.state.icon,
      dismiss: this.hideAllToasts
    });
  }
}
exports.ToastManager = ToastManager;
var _default = exports.default = ToastManager;
//# sourceMappingURL=ToastManager.js.map