import { Animated, Dimensions } from 'react-native';
import React, { Component } from 'react';
import { Gesture } from 'react-native-gesture-handler';
import Toast from './Toast';
export class ToastManager extends Component {
  defaultToastPosition = -Dimensions.get('window').height;
  defaultToastDuration = 2000;
  constructor(props) {
    super(props);
    ToastManager.toastInstance = this;
    this.state = {
      visible: false,
      duration: this.defaultToastDuration,
      autoDismiss: true,
      dismissMode: 'tap',
      showProgress: false,
      bounce: true,
      centerText: false,
      toastSpeed: 500,
      toastMessage: "",
      backgroundColor: '#aaa',
      style: undefined,
      icon: undefined,
      withIcon: true,
      dismissGesture: Gesture.Tap().runOnJS(true).onEnd(() => {
        this.hideAllToasts();
      })
    };
    this.progressValue = new Animated.Value(0);
    this.topValue = new Animated.Value(this.defaultToastPosition);
    this.hideToastTimeout;
  }
  static success(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#14A44D'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/check.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static info(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#54B4D3'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static error(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#DC4C64'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/error.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static warning(text, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#E4A11B'
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  static styled(text, style, options) {
    ToastManager.toastInstance.show(text, options);
    setTimeout(() => {
      ToastManager.toastInstance.setState({
        backgroundColor: '#E4A11B',
        style
      });
      if ((options === null || options === void 0 ? void 0 : options.withIcon) !== false) {
        ToastManager.toastInstance.setState({
          icon: (options === null || options === void 0 ? void 0 : options.icon) ?? require('../assets/icons/info.png')
        });
      } else {
        ToastManager.toastInstance.setState({
          icon: undefined
        });
      }
    }, 500);
  }
  show = (text, options) => {
    this.hideAllToasts();
    setTimeout(() => {
      let duration = (options === null || options === void 0 ? void 0 : options.duration) ?? this.defaultToastDuration;
      let autoDismiss = (options === null || options === void 0 ? void 0 : options.autoDismiss) !== true;
      console.log("Showing toast on", this.props);
      this.setState({
        toastMessage: text,
        showProgress: (options === null || options === void 0 ? void 0 : options.progress) ?? false,
        centerText: (options === null || options === void 0 ? void 0 : options.centerText) ?? false,
        bounce: (options === null || options === void 0 ? void 0 : options.bounce) ?? false,
        visible: true,
        duration,
        autoDismiss
      });
      if ((options === null || options === void 0 ? void 0 : options.dismissMode) == 'swipe') {
        this.setState({
          dismissGesture: Gesture.Pan().runOnJS(true).onUpdate(gesture => {
            if (gesture.translationY < 0) {
              this.hideAllToasts();
            }
          })
        });
      }
    }, 200);
  };
  hideAllToasts = () => {
    this.setState({
      visible: false
    });
  };
  render() {
    return /*#__PURE__*/React.createElement(Toast, {
      visible: this.state.visible,
      duration: this.state.duration,
      progress: this.state.showProgress,
      bounce: this.state.bounce,
      autoDismiss: this.state.autoDismiss,
      centerText: this.state.centerText,
      dismissGesture: this.state.dismissGesture,
      style: [this.state.style ?? {}, {
        backgroundColor: this.state.backgroundColor
      }],
      message: this.state.toastMessage,
      icon: this.state.icon,
      dismiss: this.hideAllToasts
    });
  }
}
export default ToastManager;
//# sourceMappingURL=ToastManager.js.map